"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initScript = void 0;
const initScript = (envId, config) => {
    window.heapReadyCb = window.heapReadyCb || [];
    window.heap = window.heap || {};
    window.heap.load = function (envId, clientConfig = { disableTextCapture: false, secureCookie: false }) {
        window.heap.envId = envId;
        window.heap.clientConfig = clientConfig;
        window.heap.clientConfig.shouldFetchServerConfig = false;
        const methods = [
            'init',
            'startTracking',
            'stopTracking',
            'track',
            'resetIdentity',
            'identify',
            'identifyHashed',
            'getSessionId',
            'getUserId',
            'getIdentity',
            'addUserProperties',
            'addEventProperties',
            'removeEventProperty',
            'clearEventProperties',
            'addAccountProperties',
            'addAdapter',
            'addTransformer',
            'addTransformerFn',
            'onReady',
            'addPageviewProperties',
            'removePageviewProperty',
            'clearPageviewProperties',
            'trackPageview'
        ];
        const createMethodProxy = (methodName) => {
            return function (...args) {
                window.heapReadyCb.push({
                    name: methodName,
                    fn: () => {
                        if (window.heap[methodName]) {
                            window.heap[methodName](...args);
                        }
                    }
                });
            };
        };
        for (const method of methods) {
            window.heap[method] = createMethodProxy(method);
        }
    };
    window.heap.load(envId, config);
};
exports.initScript = initScript;
//# sourceMappingURL=init-script.js.map